summary refs log tree commit diff
path: root/synapse
diff options
context:
space:
mode:
authorErik Johnston <erik@matrix.org>2018-10-25 15:25:21 +0100
committerErik Johnston <erik@matrix.org>2018-10-25 15:25:21 +0100
commite5481b22aac800b016e05f50a50ced85a226b364 (patch)
tree4fa4dfed6d4154e61a71205fdfd098d1aae989f6 /synapse
parentUse match rather than search (diff)
downloadsynapse-e5481b22aac800b016e05f50a50ced85a226b364.tar.xz
Use allow/deny
Diffstat (limited to 'synapse')
-rw-r--r--synapse/config/room_directory.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/synapse/config/room_directory.py b/synapse/config/room_directory.py
index 2ca010afdb..9da13ab11b 100644
--- a/synapse/config/room_directory.py
+++ b/synapse/config/room_directory.py
@@ -35,13 +35,13 @@ class RoomDirectoryConfig(Config):
         # The format of this option is a list of rules that contain globs that
         # match against user_id and the new alias (fully qualified with server
         # name). The action in the first rule that matches is taken, which can
         # currently either be "allowed" or "denied".
         #
         # If no rules match the request is denied.
         alias_creation_rules:
             - user_id: "*"
               alias: "*"
-              action: allowed
+              action: allow
         """
 
     def is_alias_creation_allowed(self, user_id, alias):
@@ -56,7 +56,7 @@ class RoomDirectoryConfig(Config):
         """
         for rule in self._alias_creation_rules:
             if rule.matches(user_id, alias):
-                return rule.action == "allowed"
+                return rule.action == "allow"
 
         return False
 
@@ -67,12 +67,12 @@ class _AliasRule(object):
         user_id = rule["user_id"]
         alias = rule["alias"]
 
-        if action in ("allowed", "denied"):
+        if action in ("allow", "deny"):
             self.action = action
         else:
             raise ConfigError(
-                "alias_creation_rules rules can only have action of 'allowed'"
-                " or 'denied'"
+                "alias_creation_rules rules can only have action of 'allow'"
+                " or 'deny'"
             )
 
         try:
@@ -35,13 +35,13 @@ class RoomDirectoryConfig(Config):
         # match against user_id and the new alias (fully qualified with server
         # name). The action in the first rule that matches is taken, which can
-        # currently either be "allowed" or "denied".
+        # currently either be "allow" or "deny".
         #
         # If no rules match the request is denied.